#
# spec file for package jython
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pyver %(python3 -c 'import sys;print(sys.version[0:3])')
%global cpython_version    %{pyver}
%global pyxml_version      %{pyver}
%global _python_bytecompile_errors_terminate_build 0
Name:           jython
Version:        2.7.3
Release:        1.1
Summary:        A Java implementation of the Python language
License:        Apache-2.0 AND Python-2.0
Group:          Development/Languages/Python
URL:            https://www.jython.org/
Source0:        %{name}-%{version}.tar.xz
Patch0:         %{name}-build.patch
Patch1:         %{name}-dont-validate-pom.patch
Patch2:         %{name}-cachedir.patch
Patch3:         %{name}-fix-tty-detection.patch
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  antlr3-java
BuildRequires:  antlr3-tool
BuildRequires:  apache-commons-compress
BuildRequires:  fdupes
BuildRequires:  glassfish-servlet-api
BuildRequires:  guava
BuildRequires:  jansi
BuildRequires:  jarjar
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  jffi
BuildRequires:  jline
BuildRequires:  jnr-constants
BuildRequires:  jnr-ffi
BuildRequires:  jnr-posix
BuildRequires:  lucene-core
BuildRequires:  objectweb-asm
BuildRequires:  python3 >= %{cpython_version}
BuildRequires:  python3-xml >= %{pyxml_version}
BuildRequires:  stringtemplate4
Requires:       antlr3-java
Requires:       antlr3-tool
Requires:       apache-commons-compress
Requires:       glassfish-servlet-api
Requires:       guava
Requires:       jansi
Requires:       jarjar
Requires:       jffi
Requires:       jline
Requires:       jnr-constants
Requires:       jnr-ffi
Requires:       jnr-posix
Requires:       junit
Requires:       lucene-core
Requires:       objectweb-asm
Requires:       stringtemplate4
Obsoletes:      %{name}-manual

%description
Jython is an implementation of the high-level, dynamic, object-oriented
language Python seamlessly integrated with the Java platform. The
predecessor to Jython, JPython, is certified as 100% Pure Java. Jython
is freely available for both commercial and noncommercial use and is
distributed with source code. Jython is complementary to Java and is
especially suited for the following tasks: Embedded scripting--Java
programmers can add the Jython libraries to their system to allow end
users to write simple or complicated scripts that add functionality to
the application. Interactive experimentation--Jython provides an
interactive interpreter that can be used to interact with Java packages
or with running Java applications. This allows programmers to
experiment and debug any Java system using Jython. Rapid application
development--Python programs are typically 2-10X shorter than the
equivalent Java program. This translates directly to increased
programmer productivity. The seamless interaction between Python and
Java allows developers to freely mix the two languages both during
development and in shipping products.

%package javadoc
Summary:        Javadoc for jython
Group:          Development/Libraries/Java
Provides:       jython-manual = %{version}
Obsoletes:      jython-manual < %{version}
BuildArch:      noarch

%description javadoc
API documentation for %{name}.

%package demo
Summary:        Demonstration and samples for jython
Group:          Development/Libraries/Java
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description demo
Demonstrations and samples for %{name}.

%prep
%autosetup -p1

%build
build-jar-repository -s -p extlibs \
    jffi/jffi \
    antlr3 \
    antlr3-runtime \
    commons-compress \
    glassfish-servlet-api \
    guava/guava \
    jansi/jansi \
    jarjar \
    jline/jline \
    jnr/jnr-constants \
    jnr/jnr-ffi \
    jnr/jnr-posix \
    junit \
    lucene/lucene-core \
    objectweb-asm/asm \
    objectweb-asm/asm-commons \
    objectweb-asm/asm-util \
    stringtemplate4/ST4

%{ant} -Djython.version=%{version}

pushd maven
%{ant} -Djython.version=%{version} bundle
popd

# Symlink run-time libs
rm dist/javalib/*.jar
build-jar-repository -s -p dist/javalib \
    jffi/jffi \
    antlr3 \
    antlr3-runtime \
    commons-compress \
    glassfish-servlet-api \
    guava/guava \
    jansi/jansi \
    jarjar \
    jline/jline \
    jnr/jnr-constants \
    jnr/jnr-ffi \
    jnr/jnr-posix \
    junit \
    lucene/lucene-core \
    objectweb-asm/asm \
    objectweb-asm/asm-commons \
    objectweb-asm/asm-util \
    stringtemplate4/ST4

# remove shebangs from python files
find dist -type f -name '*.py' | xargs sed -i "s:#!\s*/usr.*::"

# fix env-script-interpreter
sed -i 's/env bash/bash/' dist/bin/%{name}{,.py}

%install
# jar
install -d -m 755 %{buildroot}%{_javadir}
install -m 644 dist/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar
# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -m 644 build/maven/%{name}-%{version}.pom %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar -a org.python:jython-standalone,jython:jython

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr dist/Doc/javadoc/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

# jython home dir
install -d -m 755 %{buildroot}%{_libdir}/%{name}
ln -s %{_javadir}/%{name}.jar %{buildroot}%{_libdir}/%{name}
ln -s %{_javadir}/%{name}.jar %{buildroot}%{_libdir}/%{name}/%{name}-dev.jar
cp -pr dist/javalib %{buildroot}%{_libdir}/%{name}
rm dist/bin/jython_regrtest.bat
rm dist/bin/jython.exe
cp -pr dist/bin %{buildroot}%{_libdir}/%{name}
install -m 644 dist/registry %{buildroot}%{_libdir}/%{name}

# libs without tests
rm -rf dist/Lib/{distutils/tests,email/test,json/tests,test,unittest/test}
cp -pr dist/Lib %{buildroot}%{_libdir}/%{name}
%fdupes -s %{buildroot}%{_libdir}/%{name}/Lib

# demo
install -d -m 755 %{buildroot}%{_datadir}/%{name}
cp -pr Demo %{buildroot}%{_datadir}/%{name}
%fdupes -s %{buildroot}%{_datadir}/%{name}/Demo

# javadoc
install -d -m 755 %{buildroot}%{_datadir}/%{name}/Doc
ln -s %{_javadocdir}/%{name} %{buildroot}%{_datadir}/%{name}/Doc/javadoc

# scripts
install -d %{buildroot}%{_bindir}
ln -s %{_libdir}/%{name}/bin/jython %{buildroot}%{_bindir}

%files -f .mfiles
%doc ACKNOWLEDGMENTS NEWS README.txt
%license LICENSE.txt
%attr(0755,root,root) %{_bindir}/%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/bin
%{_libdir}/%{name}/javalib
%{_libdir}/%{name}/jython.jar
%{_libdir}/%{name}/jython-dev.jar
%{_libdir}/%{name}/Lib
%{_libdir}/%{name}/registry

%files javadoc
%license LICENSE.txt
%{_javadocdir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/Doc

%files demo
%license LICENSE.txt
%{_datadir}/%{name}/Demo

%changelog
* Wed Jun 28 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 2.7.3: [bsc#1186065]
  * See full changelog in the NEWS file.
  * Fetch sources by source _service in order to exclude
    the different binary jar files
  * Add jython-fix-tty-detection.patch
  * Rebase patches:
  - jython-dont-validate-pom.patch
  - jython-build.patch
  - jython-cachedir.patch
  * Remove patches fixed upstream:
  - jython-makeCompiledFilename.patch
  - jython-module.patch
  - jython-nofullbuildpath.patch
  - jython-cacheperms.patch
  - jython-compareto.patch
  - jython-sourcetarget.patch
  - jython-cached-classes.patch
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * jython-sourcetarget.patch
    + build with java source and tartget level 1.8
* Mon Jun 21 2021 Matej Cepl <mcepl@suse.com>
- Change dependencies to Python 3
* Wed Jun 26 2019 Fridrich Strba <fstrba@suse.com>
- Add maven artifact alias
* Tue Feb 12 2019 Fridrich Strba <fstrba@suse.com>
- Build against jline1, a compatibility package
* Fri Nov 23 2018 Fridrich Strba <fstrba@suse.com>
- Distribute the maven pom file and generate the mvn(...) provides
- Added patch:
  * jython-dont-validate-pom.patch
    + Do not validate the pom.xml file during the build
* Mon Dec 18 2017 fstrba@suse.com
- Require java 8 or higher to build.
* Mon Sep 18 2017 fstrba@suse.com
- Removed patch:
  * jython-javadoc.patch
  - Not needed, since doclint is disabled by default
* Sun Sep 10 2017 fstrba@suse.com
- Added patches:
  * jython-compareto.patch
  * jython-module.patch
    + Fix build breakages with jdk9
  * jython-javadoc.patch
    + Disable doclint in order not to die on javadoc formatting
    errors
  * jython-sourcetarget.patch
    + Specify java target and source level 1.6 in order to allow
    building with jdk9
- Depend on jline
  * Fixes missing symbols with javadoc and jdk9
* Wed Jun 28 2017 tchvatal@suse.com
- Drop bogus ht2html dependency
* Tue Jul 21 2015 tchvatal@suse.com
- Do not add release to the readline requirement
* Wed Feb  4 2015 tchvatal@suse.com
- Added patches to fix CVE-2013-2027 bnc#916224:
  * jython-cached-classes.patch
  * jython-cacheperms.patch
  * jython-makeCompiledFilename.patch
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Mar 13 2012 cfarrell@suse.com
- license update: Python-2.0 and Apache-2.0
  Use SPDX format
* Tue Feb 28 2012 mvyskocil@suse.cz
- do not require mysql-connector-java, just recommend
  to break some build cycles
* Fri Mar 11 2011 mvyskocil@suse.cz
- Update to 2.2.1 - this obsolete the pyxml patch
- merge with jython-2.2.1-6.fc16.src.rpm
* Tue Feb 22 2011 coolo@novell.com
- do not copy pyxml, python 2.7's xml support is good enough
* Sun Sep 17 2006 ro@suse.de
- set source=1.4 for java
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Sep 11 2005 ro@suse.de
- remove epoch leftover
* Thu Jul 28 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 25 2005 jsmeix@suse.de
- Current version 2.2 from JPackage.org
* Tue Sep  7 2004 ro@suse.de
- fix lib64 issue
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 2.2 (JPackage 1.5)
